@@ -1,5 +1,5 @@
-__version__ = "5.2.0"
-__keywords__ = ["aes cipher cbc ctr gcm stream block encrypt decrypt iv file wrapper reader writer"]
+__version__ = "6.0.0"
+__keywords__ = ["aes cipher cbc ctr gcm stream block encrypt decrypt nonce iv file wrapper reader writer"]
 
 
 if not __version__.endswith(".0"):
