@@ -1,9 +1,9 @@
-from .ctr import AESCipherCTR
 from omnitools import try_utf8e
+from .ctr import AESCipherCTR
 
 
 class AESCipherCTRFileBase:
-    def __init__(self, fp: str, mode: str = "a", buffer: int = 8192, cb_before= None, cb_after = None, **kwargs):
+    def __init__(self, *, fp: str, mode: str = "a", buffer: int = 8192, cb_before= None, cb_after = None, **kwargs):
         if type(self) is AESCipherCTRFileBase:
             raise NotImplementedError
         if isinstance(fp, str):
@@ -31,7 +31,6 @@ class AESCipherCTRFileBase:
         if buf:
             if self.cb_before:
                 self.cb_before(buf)
-                print(len(buf), "B\n")
             buf = try_utf8e(self.crypto(buf))
             if self.cb_after:
                 self.cb_after(buf)
@@ -61,6 +60,9 @@ class AESCipherCTRFileBase:
     def tell(self):
         return self.fo.tell()
 
+    def __del__(self):
+        self.close()
+
 
 class AESCipherCTRFileReader(AESCipherCTRFileBase):
     def __init__(self, *args, **kwargs):
