@@ -6,7 +6,7 @@ from omnitools import randb
 # supply decrypted data to high level program
 # use cb_before and cb_after to handle events before and after decryption
 reader = AESCipherCTRFileDecReader(
-    "ciphertext.txt",
+    fp="ciphertext.txt",
     buffer=8192,
     cb_before=lambda x: print("before", x),
     cb_after=lambda x: print("after", x),
