@@ -6,7 +6,7 @@ from omnitools import randb
 # write decrypted data to file
 # use cb_before and cb_after to handle events before and after decryption
 writer = AESCipherCTRFileDecWriter(
-    "decrypted.txt",
+    fp="decrypted.txt",
     buffer=8192,
     cb_before=lambda x: print("before", x),
     cb_after=lambda x: print("after", x),
